/*
 * Copyright (C) 2022-2025 Seagull Developers
 *
 * Seagull is the legal property of its developers, whose names are too
 * numerous to list here. Please refer to the AUTHORS file distributed
 * with this source distribution
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(SEAGULL_GLOBAL_HEADER_INSIDE) && !defined(SEAGULL_COMPILATION)
# error "only <seagull.h> may be included directly"
#endif

#ifndef SEAGULL_TYPES_H
#define SEAGULL_TYPES_H

#include <glib.h>
#include <gio/gio.h>

#include "seagullversion.h"

/**
 * SeagullSqlite3:
 *
 * A sqlite3 connection.
 *
 * This type alias exists to avoid requiring the sqlite3 header, but is no
 * different from the `sqlite3` type.
 *
 * If that header is included first, this will be exactly equivalent, otherwise
 * it will be a generic `gpointer`, which you should cast to a `sqlite3`.
 *
 * Since: 0.1
 */
SEAGULL_AVAILABLE_TYPE_IN_0_1
#ifdef SQLITE_API
typedef sqlite3 SeagullSqlite3;
#else
typedef gpointer SeagullSqlite3;
#endif

/**
 * SeagullSqlite3Stmt:
 *
 * A sqlite3_stmt alias.
 *
 * This type alias exists to avoid requiring the sqlite3 header, but is no
 * different from the `sqlite3_stmt` type.
 *
 * If that header is included first, this will be exactly equivalent, otherwise
 * it will be a generic `gpointer`, which you should cast to a `sqlite3_stmt`.
 *
 * Since: 0.3
 */
SEAGULL_AVAILABLE_TYPE_IN_0_3
#ifdef SQLITE_API
typedef sqlite3_stmt SeagullSqlite3Stmt;
#else
typedef gpointer SeagullSqlite3Stmt;
#endif

#endif /* SEAGULL_TYPES_H */
